==> web-9.0.0.tgz: package/lib/calendar/CalendarSearsonView.js <==
import * as React from "react";
const searsonFormatter = ["", "一季度", "二季度", "三季度", "四季度"];
export default class CalendarSearsonView extends React.PureComponent {
    getSeasonItemArr() {
        const { curTime: { year, searson }, selTimeObj, clickSelHandle, showTimeObj, } = this.props;
        const selYear = selTimeObj.get("year");
        const selSearson = selTimeObj.get("searson");
        const showYear = showTimeObj.get("year");
        let startSearson = 0;
        const isSearsonToday = year === showYear;
        const isSearsonSel = selYear === showYear;
        return Array.from({ length: 2 }, (...args) => args[1] + 1).map(row => {
            const item = Array.from({ length: 2 }, (...args) => args[1] + 1).map(() => {
                const num = ++startSearson;
                const searsonToday = (isSearsonToday && searson === num && "calendar-today") || "";
                const searsonSel = (isSearsonSel && selSearson === num && "calendar-sel") || "";
                const className = "view-item " + searsonToday + " " + searsonSel;
                return (React.createElement("li", { "data-num": num, key: num, "data-sign": "searson", className: className, onClick: (!searsonSel && clickSelHandle) || undefined },
                    React.createElement("span", { className: "searson-span" }, searsonFormatter[num])));
            });
            return (React.createElement("ul", { className: "searson-group", key: row }, item));
        });
    }
    render() {
        return (React.createElement("div", { className: "m-searsonView item-calendar-view" }, this.getSeasonItemArr()));
    }
}

==> web-11.0.2.tgz: package/lib/calendar/CalendarSearsonView.js <==
import * as React from "react";
const searsonFormatter = ["", "一季度", "二季度", "三季度", "四季度"];
export default class CalendarSearsonView extends React.PureComponent {
    getSeasonItemArr() {
        const { curTime: { year, searson }, selTimeObj, clickSelHandle, showTimeObj, } = this.props;
        const selYear = selTimeObj.get("year");
        const selSearson = selTimeObj.get("searson");
        const showYear = showTimeObj.get("year");
        let startSearson = 0;
        const isSearsonToday = year === showYear;
        const isSearsonSel = selYear === showYear;
        return Array.from({ length: 2 }, (...args) => args[1] + 1).map((row) => {
            const item = Array.from({ length: 2 }, (...args) => args[1] + 1).map(() => {
                const num = ++startSearson;
                const searsonToday = (isSearsonToday && searson === num && "calendar-today") || "";
                const searsonSel = (isSearsonSel && selSearson === num && "calendar-sel") || "";
                const className = "view-item " + searsonToday + " " + searsonSel;
                return (React.createElement("li", { "data-num": num, key: num, "data-sign": "searson", className: className, onClick: (!searsonSel && clickSelHandle) || undefined },
                    React.createElement("span", { className: "searson-span" }, searsonFormatter[num])));
            });
            return (React.createElement("ul", { className: "searson-group", key: row }, item));
        });
    }
    render() {
        return (React.createElement("div", { className: "m-searsonView item-calendar-view" }, this.getSeasonItemArr()));
    }
}
